@@ -1,3 +1,4 @@
+#define USE_FC_LEN_T
 #include <string>
 #include "util.h"
 #include "rpg.h"
@@ -12,6 +13,9 @@
 #include <R_ext/Linpack.h>
 #include <R_ext/Lapack.h>
 #include <R_ext/BLAS.h>
+#ifndef FCONE
+# define FCONE
+#endif
 
 extern "C" {
   SEXP lfMsPGOcc(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP XRE_r, SEXP XpRE_r, 
@@ -293,37 +297,37 @@ extern "C" {
 
     // For normal community-level priors
     // Occurrence coefficients
-    F77_NAME(dpotrf)(lower, &pOcc, SigmaBetaCommInv, &pOcc, &info); 
+    F77_NAME(dpotrf)(lower, &pOcc, SigmaBetaCommInv, &pOcc, &info FCONE); 
     if(info != 0){error("c++ error: dpotrf SigmaBetaCommInv failed\n");}
-    F77_NAME(dpotri)(lower, &pOcc, SigmaBetaCommInv, &pOcc, &info); 
+    F77_NAME(dpotri)(lower, &pOcc, SigmaBetaCommInv, &pOcc, &info FCONE); 
     if(info != 0){error("c++ error: dpotri SigmaBetaCommInv failed\n");}
     double *SigmaBetaCommInvMuBeta = (double *) R_alloc(pOcc, sizeof(double)); 
     // dgemv computes linear combinations of different variables. 
-    F77_NAME(dgemv)(ntran, &pOcc, &pOcc, &one, SigmaBetaCommInv, &pOcc, muBetaComm, &inc, &zero, SigmaBetaCommInvMuBeta, &inc); 	  
+    F77_NAME(dgemv)(ntran, &pOcc, &pOcc, &one, SigmaBetaCommInv, &pOcc, muBetaComm, &inc, &zero, SigmaBetaCommInvMuBeta, &inc FCONE); 	  
     // Detection regression coefficient priors. 
-    F77_NAME(dpotrf)(lower, &pDet, SigmaAlphaCommInv, &pDet, &info); 
+    F77_NAME(dpotrf)(lower, &pDet, SigmaAlphaCommInv, &pDet, &info FCONE); 
     if(info != 0){error("c++ error: dpotrf SigmaAlphaCommInv failed\n");}
-    F77_NAME(dpotri)(lower, &pDet, SigmaAlphaCommInv, &pDet, &info); 
+    F77_NAME(dpotri)(lower, &pDet, SigmaAlphaCommInv, &pDet, &info FCONE); 
     if(info != 0){error("c++ error: dpotri SigmaAlphaCommInv failed\n");}
     double *SigmaAlphaCommInvMuAlpha = (double *) R_alloc(pDet, sizeof(double)); 
-    F77_NAME(dgemv)(ntran, &pDet, &pDet, &one, SigmaAlphaCommInv, &pDet, muAlphaComm, &inc, &zero, SigmaAlphaCommInvMuAlpha, &inc); 
+    F77_NAME(dgemv)(ntran, &pDet, &pDet, &one, SigmaAlphaCommInv, &pDet, muAlphaComm, &inc, &zero, SigmaAlphaCommInvMuAlpha, &inc FCONE); 
     // Put community level occurrence variances in a pOcc x pOcc matrix.
     double *TauBetaInv = (double *) R_alloc(ppOcc, sizeof(double)); zeros(TauBetaInv, ppOcc); 
     for (i = 0; i < pOcc; i++) {
       TauBetaInv[i * pOcc + i] = tauSqBeta[i]; 
     } // i
-    F77_NAME(dpotrf)(lower, &pOcc, TauBetaInv, &pOcc, &info); 
+    F77_NAME(dpotrf)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
     if(info != 0){error("c++ error: dpotrf TauBetaInv failed\n");}
-    F77_NAME(dpotri)(lower, &pOcc, TauBetaInv, &pOcc, &info); 
+    F77_NAME(dpotri)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
     if(info != 0){error("c++ error: dpotri TauBetaInv failed\n");}
     // Put community level detection variances in a pDet x pDet matrix. 
     double *TauAlphaInv = (double *) R_alloc(ppDet, sizeof(double)); zeros(TauAlphaInv, ppDet); 
     for (i = 0; i < pDet; i++) {
       TauAlphaInv[i * pDet + i] = tauSqAlpha[i]; 
     } // i
-    F77_NAME(dpotrf)(lower, &pDet, TauAlphaInv, &pDet, &info); 
+    F77_NAME(dpotrf)(lower, &pDet, TauAlphaInv, &pDet, &info FCONE); 
     if(info != 0){error("c++ error: dpotrf TauAlphaInv failed\n");}
-    F77_NAME(dpotri)(lower, &pDet, TauAlphaInv, &pDet, &info); 
+    F77_NAME(dpotri)(lower, &pDet, TauAlphaInv, &pDet, &info FCONE); 
     if(info != 0){error("c++ error: dpotri TauAlphaInv failed\n");}
 
     /**********************************************************************
@@ -369,7 +373,7 @@ extern "C" {
     double *wStar = (double *) R_alloc(JN, sizeof(double)); zeros(wStar, JN);
     // Multiply Lambda %*% w[j] to get wStar. 
     for (j = 0; j < J; j++) {
-      F77_NAME(dgemv)(ntran, &N, &q, &one, lambda, &N, &w[j*q], &inc, &zero, &wStar[j * N], &inc);
+      F77_NAME(dgemv)(ntran, &N, &q, &one, lambda, &N, &w[j*q], &inc, &zero, &wStar[j * N], &inc FCONE);
     }
     double *mu = (double *) R_alloc(q, sizeof(double));
     double *var = (double *) R_alloc(qq, sizeof(double));
@@ -389,7 +393,7 @@ extern "C" {
        *******************************/
       zeros(tmp_pOcc, pOcc); 
       for (i = 0; i < N; i++) {
-        F77_NAME(dgemv)(ytran, &pOcc, &pOcc, &one, TauBetaInv, &pOcc, &beta[i], &N, &one, tmp_pOcc, &inc); 
+        F77_NAME(dgemv)(ytran, &pOcc, &pOcc, &one, TauBetaInv, &pOcc, &beta[i], &N, &one, tmp_pOcc, &inc FCONE); 
       } // i
       for (h = 0; h < pOcc; h++) {
         tmp_pOcc[h] += SigmaBetaCommInvMuBeta[h];  
@@ -401,15 +405,15 @@ extern "C" {
       for (h = 0; h < ppOcc; h++) {
         tmp_ppOcc[h] = SigmaBetaCommInv[h] + N * TauBetaInv[h]; 
       }
-      F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info); 
+      F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
       if(info != 0){error("c++ error: dpotrf ABetaComm failed\n");}
-      F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info); 
+      F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
       if(info != 0){error("c++ error: dpotri ABetaComm failed\n");}
       // A.beta.inv %*% b.beta
       // 1 * tmp_ppOcc * tmp_pOcc + 0 * tmp_pOcc2  = tmp_pOcc2
-      F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc);
+      F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc FCONE);
       // Computes cholesky of tmp_pp again stored back in tmp_ppOcc. This chol(A.beta.inv)
-      F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info); 
+      F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
       if(info != 0){error("c++ error: dpotrf ABetaComm failed\n");}
       // Args: destination, mu, cholesky of the inverse covariance matrix, dimension
       mvrnorm(betaComm, tmp_pOcc2, tmp_ppOcc, pOcc);
@@ -422,7 +426,7 @@ extern "C" {
        *******************************/
        zeros(tmp_pDet, pDet); 
        for (i = 0; i < N; i++) {
-         F77_NAME(dgemv)(ytran, &pDet, &pDet, &one, TauAlphaInv, &pDet, &alpha[i], &N, &one, tmp_pDet, &inc); 
+         F77_NAME(dgemv)(ytran, &pDet, &pDet, &one, TauAlphaInv, &pDet, &alpha[i], &N, &one, tmp_pDet, &inc FCONE); 
        } // i
        for (h = 0; h < pDet; h++) {
          tmp_pDet[h] += SigmaAlphaCommInvMuAlpha[h];  
@@ -433,15 +437,15 @@ extern "C" {
       for (h = 0; h < ppDet; h++) {
         tmp_ppDet[h] = SigmaAlphaCommInv[h] + N * TauAlphaInv[h]; 
       }
-      F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info); 
+      F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
       if(info != 0){error("c++ error: dpotrf AAlphaComm failed\n");}
-      F77_NAME(dpotri)(lower, &pDet, tmp_ppDet, &pDet, &info); 
+      F77_NAME(dpotri)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
       if(info != 0){error("c++ error: dpotri AAlphaComm failed\n");}
       // A.alpha.inv %*% b.alpha
       // 1 * tmp_ppDet * tmp_pDet + 0 * tmp_pDet2  = tmp_pDet2
-      F77_NAME(dsymv)(lower, &pDet, &one, tmp_ppDet, &pDet, tmp_pDet, &inc, &zero, tmp_pDet2, &inc);
+      F77_NAME(dsymv)(lower, &pDet, &one, tmp_ppDet, &pDet, tmp_pDet, &inc, &zero, tmp_pDet2, &inc FCONE);
       // Computes cholesky of tmp_pp again stored back in tmp_ppDet. This chol(A.alpha.inv)
-      F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info); 
+      F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
       if(info != 0){error("c++ error: dpotrf AAlphaComm failed\n");}
       // Args: destination, mu, cholesky of the inverse covariance matrix, dimension
       mvrnorm(alphaComm, tmp_pDet2, tmp_ppDet, pDet);
@@ -461,9 +465,9 @@ extern "C" {
       for (h = 0; h < pOcc; h++) {
         TauBetaInv[h * pOcc + h] = tauSqBeta[h]; 
       } // i
-      F77_NAME(dpotrf)(lower, &pOcc, TauBetaInv, &pOcc, &info); 
+      F77_NAME(dpotrf)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
       if(info != 0){error("c++ error: dpotrf TauBetaInv failed\n");}
-      F77_NAME(dpotri)(lower, &pOcc, TauBetaInv, &pOcc, &info); 
+      F77_NAME(dpotri)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
       if(info != 0){error("c++ error: dpotri TauBetaInv failed\n");}
       /********************************************************************
        Update Community Detection Variance Parameter
@@ -479,9 +483,9 @@ extern "C" {
       for (h = 0; h < pDet; h++) {
         TauAlphaInv[h * pDet + h] = tauSqAlpha[h]; 
       } // i
-      F77_NAME(dpotrf)(lower, &pDet, TauAlphaInv, &pDet, &info); 
+      F77_NAME(dpotrf)(lower, &pDet, TauAlphaInv, &pDet, &info FCONE); 
       if(info != 0){error("c++ error: dpotrf TauAlphaInv failed\n");}
-      F77_NAME(dpotri)(lower, &pDet, TauAlphaInv, &pDet, &info); 
+      F77_NAME(dpotri)(lower, &pDet, TauAlphaInv, &pDet, &info FCONE); 
       if(info != 0){error("c++ error: dpotri TauAlphaInv failed\n");}
 
       /********************************************************************
@@ -550,9 +554,9 @@ extern "C" {
          *******************************/
         // t(X) * tmp_J1 + 0 * tmp_pOcc = tmp_pOcc. 
         // dgemv computes linear combinations of different variables. 
-        F77_NAME(dgemv)(ytran, &J, &pOcc, &one, X, &J, tmp_J1, &inc, &zero, tmp_pOcc, &inc); 	 
+        F77_NAME(dgemv)(ytran, &J, &pOcc, &one, X, &J, tmp_J1, &inc, &zero, tmp_pOcc, &inc FCONE); 	 
         // TauBetaInv %*% betaComm + tmp_pOcc = tmp_pOcc
-        F77_NAME(dgemv)(ntran, &pOcc, &pOcc, &one, TauBetaInv, &pOcc, betaComm, &inc, &one, tmp_pOcc, &inc); 
+        F77_NAME(dgemv)(ntran, &pOcc, &pOcc, &one, TauBetaInv, &pOcc, betaComm, &inc, &one, tmp_pOcc, &inc FCONE); 
 
         /********************************
          * Compute A.beta
@@ -565,17 +569,17 @@ extern "C" {
         }
         // This finishes off A.beta
         // 1 * X * tmp_JpOcc + 0 * tmp_ppOcc = tmp_ppOcc
-        F77_NAME(dgemm)(ytran, ntran, &pOcc, &pOcc, &J, &one, X, &J, tmp_JpOcc, &J, &zero, tmp_ppOcc, &pOcc);
+        F77_NAME(dgemm)(ytran, ntran, &pOcc, &pOcc, &J, &one, X, &J, tmp_JpOcc, &J, &zero, tmp_ppOcc, &pOcc FCONE FCONE);
         for (h = 0; h < ppOcc; h++) {
           tmp_ppOcc[h] += TauBetaInv[h]; 
         } // j
-        F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info); 
+        F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
         if(info != 0){error("c++ error: dpotrf ABeta failed\n");}
-        F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info); 
+        F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
         if(info != 0){error("c++ error: dpotri ABeta failed\n");}
         // A.beta.inv %*% b.beta
-        F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc);
-        F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info); 
+        F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc FCONE);
+        F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
 	if(info != 0){error("c++ error: dpotrf A.beta 2 failed\n");}
         // Args: destination, mu, cholesky of the covariance matrix, dimension
         mvrnorm(tmp_beta, tmp_pOcc2, tmp_ppOcc, pOcc);
@@ -606,8 +610,8 @@ extern "C" {
           } // r
         }
         
-        F77_NAME(dgemv)(ytran, &nObs, &pDet, &one, Xp, &nObs, tmp_nObs, &inc, &zero, tmp_pDet, &inc); 	  
-        F77_NAME(dgemv)(ntran, &pDet, &pDet, &one, TauAlphaInv, &pDet, alphaComm, &inc, &one, tmp_pDet, &inc); 
+        F77_NAME(dgemv)(ytran, &nObs, &pDet, &one, Xp, &nObs, tmp_nObs, &inc, &zero, tmp_pDet, &inc FCONE); 	  
+        F77_NAME(dgemv)(ntran, &pDet, &pDet, &one, TauAlphaInv, &pDet, alphaComm, &inc, &one, tmp_pDet, &inc FCONE); 
 
         /********************************
          * Compute A.alpha
@@ -620,21 +624,21 @@ extern "C" {
 
         // This finishes off A.alpha
         // 1 * Xp * tmp_nObspDet + 0 * tmp_ppDet = tmp_ppDet
-        F77_NAME(dgemm)(ytran, ntran, &pDet, &pDet, &nObs, &one, Xp, &nObs, tmp_nObspDet, &nObs, &zero, tmp_ppDet, &pDet);
+        F77_NAME(dgemm)(ytran, ntran, &pDet, &pDet, &nObs, &one, Xp, &nObs, tmp_nObspDet, &nObs, &zero, tmp_ppDet, &pDet FCONE FCONE);
 
         for (h = 0; h < ppDet; h++) {
           tmp_ppDet[h] += TauAlphaInv[h]; 
         } // h
-        F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info); 
+        F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
         if(info != 0){error("c++ error: dpotrf A.alpha failed\n");}
-        F77_NAME(dpotri)(lower, &pDet, tmp_ppDet, &pDet, &info); 
+        F77_NAME(dpotri)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
         if(info != 0){error("c++ error: dpotri A.alpha failed\n");}
         // A.alpha.inv %*% b.alpha
         // 1 * tmp_ppDet * tmp_pDet + 0 * tmp_pDet2 
         // (which is currently nothing) = tmp_pDet2
-        F77_NAME(dsymv)(lower, &pDet, &one, tmp_ppDet, &pDet, tmp_pDet, &inc, &zero, tmp_pDet2, &inc);
+        F77_NAME(dsymv)(lower, &pDet, &one, tmp_ppDet, &pDet, tmp_pDet, &inc, &zero, tmp_pDet2, &inc FCONE);
         // Computes cholesky of tmp_ppDet again stored back in tmp_ppDet. This chol(A.alpha.inv)
-        F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info); 
+        F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
         if(info != 0){error("c++ error: dpotrf A.alpha 2 failed\n");}
         // Args: destination, mu, cholesky of the covariance matrix, dimension
         mvrnorm(tmp_alpha, tmp_pDet2, tmp_ppDet, pDet);
@@ -724,15 +728,15 @@ extern "C" {
             tmp_Nq[ll * N + i] = lambda[ll * N + i] * omegaOcc[ii * N + i];
           } // ll
         } // i
-	F77_NAME(dgemm)(ytran, ntran, &q, &q, &N, &one, tmp_Nq, &N, lambda, &N, &zero, var, &q);
+	F77_NAME(dgemm)(ytran, ntran, &q, &q, &N, &one, tmp_Nq, &N, lambda, &N, &zero, var, &q FCONE FCONE);
 
 	// var
 	for (k = 0; k < q; k++) {
           var[k * q + k] += 1.0; 
         } // k
-	F77_NAME(dpotrf)(lower, &q, var, &q, &info);
+	F77_NAME(dpotrf)(lower, &q, var, &q, &info FCONE);
         if (info != 0){error("c++ error: dpotrf var failed\n");}
-	F77_NAME(dpotri)(lower, &q, var, &q, &info);
+	F77_NAME(dpotri)(lower, &q, var, &q, &info FCONE);
         if (info != 0){error("c++ error: dpotri var failed\n");}
 
 	// mu
@@ -740,11 +744,11 @@ extern "C" {
           tmp_N[k] = (zStar[ii * N + k] - F77_NAME(ddot)(&pOcc, &X[ii], &J, &beta[k], &N) - betaStarSites[k * J + ii]) * omegaOcc[ii * N + k];
         } // k
 
-	F77_NAME(dgemv)(ytran, &N, &q, &one, lambda, &N, tmp_N, &inc, &zero, mu, &inc);
+	F77_NAME(dgemv)(ytran, &N, &q, &one, lambda, &N, tmp_N, &inc, &zero, mu, &inc FCONE);
 
-        F77_NAME(dsymv)(lower, &q, &one, var, &q, mu, &inc, &zero, tmp_N, &inc);
+        F77_NAME(dsymv)(lower, &q, &one, var, &q, mu, &inc, &zero, tmp_N, &inc FCONE);
 
-	F77_NAME(dpotrf)(lower, &q, var, &q, &info); 
+	F77_NAME(dpotrf)(lower, &q, var, &q, &info FCONE); 
         if(info != 0){error("c++ error: dpotrf var 2 failed\n");}
 
 	mvrnorm(&w[ii * q], tmp_N, var, q);
@@ -816,14 +820,14 @@ extern "C" {
           tmp_qq2[j * currDim + j] += 1.0;  
         } // j
 
-        F77_NAME(dpotrf)(lower, &currDim, tmp_qq2, &currDim, &info); 
+        F77_NAME(dpotrf)(lower, &currDim, tmp_qq2, &currDim, &info FCONE); 
         if(info != 0){error("c++ error: dpotrf for spatial factors failed\n");}
-        F77_NAME(dpotri)(lower, &currDim, tmp_qq2, &currDim, &info); 
+        F77_NAME(dpotri)(lower, &currDim, tmp_qq2, &currDim, &info FCONE); 
         if(info != 0){error("c++ error: dpotri for spatial factors failed\n");}
 
-        F77_NAME(dsymv)(lower, &currDim, &one, tmp_qq2, &currDim, tmp_q, &inc, &zero, tmp_q2, &inc);
+        F77_NAME(dsymv)(lower, &currDim, &one, tmp_qq2, &currDim, tmp_q, &inc, &zero, tmp_q2, &inc FCONE);
 
-        F77_NAME(dpotrf)(lower, &currDim, tmp_qq2, &currDim, &info); 
+        F77_NAME(dpotrf)(lower, &currDim, tmp_qq2, &currDim, &info FCONE); 
         if(info != 0){error("c++ error: dpotrf for spatial factors 2 failed\n");}
         
         mvrnorm(tmp_q, tmp_q2, tmp_qq2, currDim);
@@ -832,7 +836,7 @@ extern "C" {
 
       // Multiply Lambda %*% w[j] to get wStar. 
       for (j = 0; j < J; j++) {
-        F77_NAME(dgemv)(ntran, &N, &q, &one, lambda, &N, &w[j*q], &inc, &zero, &wStar[j * N], &inc);
+        F77_NAME(dgemv)(ntran, &N, &q, &one, lambda, &N, &w[j*q], &inc, &zero, &wStar[j * N], &inc FCONE);
       } // j
 
       /********************************************************************
