@@ -1,3 +1,4 @@
+#define USE_FC_LEN_T
 #include <string>
 #include "util.h"
 #include "rpg.h"
@@ -12,6 +13,9 @@
 #include <R_ext/Linpack.h>
 #include <R_ext/Lapack.h>
 #include <R_ext/BLAS.h>
+#ifndef FCONE
+# define FCONE
+#endif
 
 extern "C" {
   SEXP spMsPGOcc(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP coordsD_r, 
@@ -301,39 +305,39 @@ extern "C" {
     double *ySum = (double *) R_alloc(JN, sizeof(double)); zeros(ySum, JN);
 
     // For normal priors
-    F77_NAME(dpotrf)(lower, &pOcc, SigmaBetaCommInv, &pOcc, &info); 
+    F77_NAME(dpotrf)(lower, &pOcc, SigmaBetaCommInv, &pOcc, &info FCONE); 
     if(info != 0){error("c++ error: dpotrf SigmaBetaCommInv failed\n");}
-    F77_NAME(dpotri)(lower, &pOcc, SigmaBetaCommInv, &pOcc, &info); 
+    F77_NAME(dpotri)(lower, &pOcc, SigmaBetaCommInv, &pOcc, &info FCONE); 
     if(info != 0){error("c++ error: dpotri SigmaBetaCommInv failed\n");}
     double *SigmaBetaCommInvMuBeta = (double *) R_alloc(pOcc, sizeof(double)); 
     // dgemv computes linear combinations of different variables. 
     F77_NAME(dsymv)(lower, &pOcc, &one, SigmaBetaCommInv, &pOcc, muBetaComm, &inc, &zero, 
-        	    SigmaBetaCommInvMuBeta, &inc);
+        	    SigmaBetaCommInvMuBeta, &inc FCONE);
     // Detection regression coefficient priors. 
-    F77_NAME(dpotrf)(lower, &pDet, SigmaAlphaCommInv, &pDet, &info); 
+    F77_NAME(dpotrf)(lower, &pDet, SigmaAlphaCommInv, &pDet, &info FCONE); 
     if(info != 0){error("c++ error: dpotrf SigmaAlphaCommInv failed\n");}
-    F77_NAME(dpotri)(lower, &pDet, SigmaAlphaCommInv, &pDet, &info); 
+    F77_NAME(dpotri)(lower, &pDet, SigmaAlphaCommInv, &pDet, &info FCONE); 
     if(info != 0){error("c++ error: dpotri SigmaAlphaCommInv failed\n");}
     double *SigmaAlphaCommInvMuAlpha = (double *) R_alloc(pDet, sizeof(double)); 
     F77_NAME(dsymv)(lower, &pDet, &one, SigmaAlphaCommInv, &pDet, muAlphaComm, &inc, &zero, 
-                   SigmaAlphaCommInvMuAlpha, &inc);
+                   SigmaAlphaCommInvMuAlpha, &inc FCONE);
     // Put community level variances in a pOcc x POcc matrix.
     double *TauBetaInv = (double *) R_alloc(ppOcc, sizeof(double)); zeros(TauBetaInv, ppOcc); 
     for (i = 0; i < pOcc; i++) {
       TauBetaInv[i * pOcc + i] = tauSqBeta[i]; 
     } // i
-    F77_NAME(dpotrf)(lower, &pOcc, TauBetaInv, &pOcc, &info); 
+    F77_NAME(dpotrf)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
     if(info != 0){error("c++ error: dpotrf TauBetaInv failed\n");}
-    F77_NAME(dpotri)(lower, &pOcc, TauBetaInv, &pOcc, &info); 
+    F77_NAME(dpotri)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
     if(info != 0){error("c++ error: dpotri TauBetaInv failed\n");}
     // Put community level variances in a pDet x pDet matrix. 
     double *TauAlphaInv = (double *) R_alloc(ppDet, sizeof(double)); zeros(TauAlphaInv, ppDet); 
     for (i = 0; i < pDet; i++) {
       TauAlphaInv[i * pDet + i] = tauSqAlpha[i]; 
     } // i
-    F77_NAME(dpotrf)(lower, &pDet, TauAlphaInv, &pDet, &info); 
+    F77_NAME(dpotrf)(lower, &pDet, TauAlphaInv, &pDet, &info FCONE); 
     if(info != 0){error("c++ error: dpotrf TauAlphaInv failed\n");}
-    F77_NAME(dpotri)(lower, &pDet, TauAlphaInv, &pDet, &info); 
+    F77_NAME(dpotri)(lower, &pDet, TauAlphaInv, &pDet, &info FCONE); 
     if(info != 0){error("c++ error: dpotri TauAlphaInv failed\n");}
 
     /**********************************************************************
@@ -409,9 +413,9 @@ extern "C" {
     spCorLT(coordsD, J, currTheta, corName, R); 
     // Get spatial covariance matrix 
     spCovLT(coordsD, J, currTheta, corName, C); 
-    F77_NAME(dpotrf)(lower, &J, C, &J, &info); 
+    F77_NAME(dpotrf)(lower, &J, C, &J, &info FCONE); 
     if(info != 0){error("c++ error: Cholesky failed in initial covariance matrix\n");}
-    F77_NAME(dpotri)(lower, &J, C, &J, &info); 
+    F77_NAME(dpotri)(lower, &J, C, &J, &info FCONE); 
     if(info != 0){error("c++ error: Cholesky inverse failed in initial covariance matrix\n");}
     SEXP thetaSamples_r; 
     PROTECT(thetaSamples_r = allocMatrix(REALSXP, nThetaN, nPost)); nProtect++; 
@@ -446,7 +450,7 @@ extern "C" {
          *******************************/
         zeros(tmp_pOcc, pOcc); 
         for (i = 0; i < N; i++) {
-          F77_NAME(dgemv)(ytran, &pOcc, &pOcc, &one, TauBetaInv, &pOcc, &beta[i], &N, &one, tmp_pOcc, &inc); 
+          F77_NAME(dgemv)(ytran, &pOcc, &pOcc, &one, TauBetaInv, &pOcc, &beta[i], &N, &one, tmp_pOcc, &inc FCONE); 
         } // i
         for (q = 0; q < pOcc; q++) {
           tmp_pOcc[q] += SigmaBetaCommInvMuBeta[q];  
@@ -458,15 +462,15 @@ extern "C" {
         for (q = 0; q < ppOcc; q++) {
           tmp_ppOcc[q] = SigmaBetaCommInv[q] + N * TauBetaInv[q]; 
         }
-        F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info); 
+        F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
         if(info != 0){error("c++ error: dpotrf ABetaComm failed\n");}
-        F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info); 
+        F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
         if(info != 0){error("c++ error: dpotri ABetaComm failed\n");}
         // A.beta.inv %*% b.beta
         // 1 * tmp_ppOcc * tmp_pOcc + 0 * tmp_pOcc2  = tmp_pOcc2
-        F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc);
+        F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc FCONE);
         // Computes cholesky of tmp_pp again stored back in tmp_ppOcc. This chol(A.beta.inv)
-        F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info); 
+        F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
         if(info != 0){error("c++ error: dpotrf ABetaComm failed\n");}
         // Args: destination, mu, cholesky of the inverse covariance matrix, dimension
         mvrnorm(betaComm, tmp_pOcc2, tmp_ppOcc, pOcc);
@@ -478,7 +482,7 @@ extern "C" {
          *******************************/
          zeros(tmp_pDet, pDet); 
          for (i = 0; i < N; i++) {
-           F77_NAME(dgemv)(ytran, &pDet, &pDet, &one, TauAlphaInv, &pDet, &alpha[i], &N, &one, tmp_pDet, &inc); 
+           F77_NAME(dgemv)(ytran, &pDet, &pDet, &one, TauAlphaInv, &pDet, &alpha[i], &N, &one, tmp_pDet, &inc FCONE); 
          } // i
          for (q = 0; q < pDet; q++) {
            tmp_pDet[q] += SigmaAlphaCommInvMuAlpha[q];  
@@ -489,15 +493,15 @@ extern "C" {
         for (q = 0; q < ppDet; q++) {
           tmp_ppDet[q] = SigmaAlphaCommInv[q] + N * TauAlphaInv[q]; 
         }
-        F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info); 
+        F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
         if(info != 0){error("c++ error: dpotrf AAlphaComm failed\n");}
-        F77_NAME(dpotri)(lower, &pDet, tmp_ppDet, &pDet, &info); 
+        F77_NAME(dpotri)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
         if(info != 0){error("c++ error: dpotri AAlphaComm failed\n");}
         // A.alpha.inv %*% b.alpha
         // 1 * tmp_ppDet * tmp_pDet + 0 * tmp_pDet2  = tmp_pDet2
-        F77_NAME(dsymv)(lower, &pDet, &one, tmp_ppDet, &pDet, tmp_pDet, &inc, &zero, tmp_pDet2, &inc);
+        F77_NAME(dsymv)(lower, &pDet, &one, tmp_ppDet, &pDet, tmp_pDet, &inc, &zero, tmp_pDet2, &inc FCONE);
         // Computes cholesky of tmp_pp again stored back in tmp_ppDet. This chol(A.alpha.inv)
-        F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info); 
+        F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
         if(info != 0){error("c++ error: dpotrf AAlphaComm failed\n");}
         // Args: destination, mu, cholesky of the inverse covariance matrix, dimension
         mvrnorm(alphaComm, tmp_pDet2, tmp_ppDet, pDet);
@@ -516,9 +520,9 @@ extern "C" {
         for (q = 0; q < pOcc; q++) {
           TauBetaInv[q * pOcc + q] = tauSqBeta[q]; 
         } // i
-        F77_NAME(dpotrf)(lower, &pOcc, TauBetaInv, &pOcc, &info); 
+        F77_NAME(dpotrf)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
         if(info != 0){error("c++ error: dpotrf TauBetaInv failed\n");}
-        F77_NAME(dpotri)(lower, &pOcc, TauBetaInv, &pOcc, &info); 
+        F77_NAME(dpotri)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
         if(info != 0){error("c++ error: dpotri TauBetaInv failed\n");}
         /********************************************************************
          Update Community Detection Variance Parameter
@@ -534,9 +538,9 @@ extern "C" {
         for (q = 0; q < pDet; q++) {
           TauAlphaInv[q * pDet + q] = tauSqAlpha[q]; 
         } // i
-        F77_NAME(dpotrf)(lower, &pDet, TauAlphaInv, &pDet, &info); 
+        F77_NAME(dpotrf)(lower, &pDet, TauAlphaInv, &pDet, &info FCONE); 
         if(info != 0){error("c++ error: dpotrf TauAlphaInv failed\n");}
-        F77_NAME(dpotri)(lower, &pDet, TauAlphaInv, &pDet, &info); 
+        F77_NAME(dpotri)(lower, &pDet, TauAlphaInv, &pDet, &info FCONE); 
         if(info != 0){error("c++ error: dpotri TauAlphaInv failed\n");}
 
         /********************************************************************
@@ -604,9 +608,9 @@ extern "C" {
            *******************************/
           // t(X) * tmp_J1 + 0 * tmp_pOcc = tmp_pOcc. 
           // dgemv computes linear combinations of different variables. 
-          F77_NAME(dgemv)(ytran, &J, &pOcc, &one, X, &J, tmp_J1, &inc, &zero, tmp_pOcc, &inc); 	 
+          F77_NAME(dgemv)(ytran, &J, &pOcc, &one, X, &J, tmp_J1, &inc, &zero, tmp_pOcc, &inc FCONE); 	 
           // TauBetaInv %*% betaComm + tmp_pOcc = tmp_pOcc
-          F77_NAME(dgemv)(ntran, &pOcc, &pOcc, &one, TauBetaInv, &pOcc, betaComm, &inc, &one, tmp_pOcc, &inc); 
+          F77_NAME(dgemv)(ntran, &pOcc, &pOcc, &one, TauBetaInv, &pOcc, betaComm, &inc, &one, tmp_pOcc, &inc FCONE); 
 
           /********************************
            * Compute A.beta
@@ -619,17 +623,18 @@ extern "C" {
           }
           // This finishes off A.beta
           // 1 * X * tmp_JpOcc + 0 * tmp_ppOcc = tmp_ppOcc
-          F77_NAME(dgemm)(ytran, ntran, &pOcc, &pOcc, &J, &one, X, &J, tmp_JpOcc, &J, &zero, tmp_ppOcc, &pOcc);
+          F77_NAME(dgemm)(ytran, ntran, &pOcc, &pOcc, &J, &one, X, &J, tmp_JpOcc, &J, &zero, tmp_ppOcc, &pOcc FCONE FCONE);
           for (q = 0; q < ppOcc; q++) {
             tmp_ppOcc[q] += TauBetaInv[q]; 
           } // j
-          F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info); 
+          F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
           if(info != 0){error("c++ error: dpotrf ABeta failed\n");}
-          F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info); 
+          F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
           if(info != 0){error("c++ error: dpotri ABeta failed\n");}
           // A.beta.inv %*% b.beta
-          F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc);
-          F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info); if(info != 0){error("c++ error: dpotrf here failed\n");}
+          F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc FCONE);
+          F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
+	  if(info != 0){error("c++ error: dpotrf here failed\n");}
           // Args: destination, mu, cholesky of the covariance matrix, dimension
           mvrnorm(tmp_beta, tmp_pOcc2, tmp_ppOcc, pOcc);
           // Can eventually get rid of this and change order of beta. 
@@ -660,8 +665,8 @@ extern "C" {
             } // r
           }
           
-          F77_NAME(dgemv)(ytran, &nObs, &pDet, &one, Xp, &nObs, tmp_nObs, &inc, &zero, tmp_pDet, &inc);  
-          F77_NAME(dgemv)(ntran, &pDet, &pDet, &one, TauAlphaInv, &pDet, alphaComm, &inc, &one, tmp_pDet, &inc); 
+          F77_NAME(dgemv)(ytran, &nObs, &pDet, &one, Xp, &nObs, tmp_nObs, &inc, &zero, tmp_pDet, &inc FCONE);  
+          F77_NAME(dgemv)(ntran, &pDet, &pDet, &one, TauAlphaInv, &pDet, alphaComm, &inc, &one, tmp_pDet, &inc FCONE); 
           /********************************
            * Compute A.alpha
            * *****************************/
@@ -674,22 +679,22 @@ extern "C" {
 
           // This finishes off A.alpha
           // 1 * Xp * tmp_nObspDet + 0 * tmp_ppDet = tmp_ppDet
-          F77_NAME(dgemm)(ytran, ntran, &pDet, &pDet, &nObs, &one, Xp, &nObs, tmp_nObspDet, &nObs, &zero, tmp_ppDet, &pDet);
+          F77_NAME(dgemm)(ytran, ntran, &pDet, &pDet, &nObs, &one, Xp, &nObs, tmp_nObspDet, &nObs, &zero, tmp_ppDet, &pDet FCONE FCONE);
 
           for (q = 0; q < ppDet; q++) {
             tmp_ppDet[q] += TauAlphaInv[q]; 
             // Rprintf("TauAlphaInv: %f\n", TauAlphaInv[q]); 
           } // q
-          F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info); 
+          F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
           if(info != 0){error("c++ error: dpotrf A.alpha failed\n");}
-          F77_NAME(dpotri)(lower, &pDet, tmp_ppDet, &pDet, &info); 
+          F77_NAME(dpotri)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
           if(info != 0){error("c++ error: dpotri A.alpha failed\n");}
           // A.alpha.inv %*% b.alpha
           // 1 * tmp_ppDet * tmp_pDet + 0 * tmp_pDet2 
           // (which is currently nothing) = tmp_pDet2
-          F77_NAME(dsymv)(lower, &pDet, &one, tmp_ppDet, &pDet, tmp_pDet, &inc, &zero, tmp_pDet2, &inc);
+          F77_NAME(dsymv)(lower, &pDet, &one, tmp_ppDet, &pDet, tmp_pDet, &inc, &zero, tmp_pDet2, &inc FCONE);
           // Computes cholesky of tmp_ppDet again stored back in tmp_ppDet. This chol(A.alpha.inv)
-          F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info); 
+          F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
           if(info != 0){error("c++ error: dpotrf here failed\n");}
           // Args: destination, mu, cholesky of the covariance matrix, dimension
           mvrnorm(tmp_alpha, tmp_pDet2, tmp_ppDet, pDet);
@@ -709,9 +714,9 @@ extern "C" {
 	  fillUTri(R, J); 
 	  // Save R in tmp_JJ
           F77_NAME(dcopy)(&JJ, R, &inc, tmp_JJ, &inc); 
-          F77_NAME(dpotrf)(lower, &J, R, &J, &info); 
+          F77_NAME(dpotrf)(lower, &J, R, &J, &info FCONE); 
           if(info != 0){error("c++ error: Cholesky failed in correlation matrix\n");}
-          F77_NAME(dpotri)(lower, &J, R, &J, &info); 
+          F77_NAME(dpotri)(lower, &J, R, &J, &info FCONE); 
           if(info != 0){error("c++ error: Cholesky inverse failed in correlation matrix\n");}
 	  fillUTri(R, J); 
 
@@ -755,20 +760,20 @@ extern "C" {
            *******************************/
 	  // Invert CCand and log det cov. 
           detCand = 0.0;
-	  F77_NAME(dpotrf)(lower, &J, CCand, &J, &info); 
+	  F77_NAME(dpotrf)(lower, &J, CCand, &J, &info FCONE); 
 	  if(info != 0){error("c++ error: Cholesky failed in covariance matrix\n");}
 	  // Get log of the determinant of the covariance matrix. 
 	  for (k = 0; k < J; k++) {
             // Rprintf("detCand Value: %f\n", 2.0 * log(CCand[k * J + k])); 
 	    detCand += 2.0 * log(CCand[k*J+k]);
 	  } // k
-	  F77_NAME(dpotri)(lower, &J, CCand, &J, &info); 
+	  F77_NAME(dpotri)(lower, &J, CCand, &J, &info FCONE); 
 	  if(info != 0){error("c++ error: Cholesky inverse failed in covariance matrix\n");}
           logPostCand = 0.0; 
 	  // Jacobian and Uniform prior. 
 	  logPostCand += log(phiCand - phiA[i]) + log(phiB[i] - phiCand); 
 	  // (-1/2) * tmp_JD` *  C^-1 * tmp_JD
-	  F77_NAME(dsymv)(lower, &J, &one,  CCand, &J, &w[i], &N, &zero, tmp_JD, &inc);
+	  F77_NAME(dsymv)(lower, &J, &one,  CCand, &J, &w[i], &N, &zero, tmp_JD, &inc FCONE);
 	  logPostCand += -0.5*detCand-0.5*F77_NAME(ddot)(&J, &w[i], &N, tmp_JD, &inc);
 	  // Rprintf("logPostCand: %f\n", logPostCand); 
           if (corName == "matern"){
@@ -781,7 +786,7 @@ extern "C" {
 	  // Get logdetCov
           detCurr = 0.0;
 	  // tmp_JJ has the current covariance matrix
-	  F77_NAME(dpotrf)(lower, &J, tmp_JJ, &J, &info); 
+	  F77_NAME(dpotrf)(lower, &J, tmp_JJ, &J, &info FCONE); 
 	  if(info != 0){error("c++ error: Cholesky failed in covariance matrix\n");}
 	  // Get log of the determinant of the covariance matrix. 
 	  for (k = 0; k < J; k++) {
@@ -792,7 +797,7 @@ extern "C" {
 	  // Jacobian and Uniform prior. 
 	  logPostCurr += log(phi[i] - phiA[i]) + log(phiB[i] - phi[i]); 
 	  // (-1/2) * tmp_JD` *  C^-1 * tmp_JD
-	  F77_NAME(dsymv)(lower, &J, &one, C, &J, &w[i], &N, &zero, tmp_JD, &inc);
+	  F77_NAME(dsymv)(lower, &J, &one, C, &J, &w[i], &N, &zero, tmp_JD, &inc FCONE);
 	  logPostCurr += -0.5*detCurr-0.5*F77_NAME(ddot)(&J, &w[i], &N, tmp_JD, &inc);
 	  // Rprintf("logPostCurr: %f\n", logPostCurr); 
           if (corName == "matern"){
@@ -831,12 +836,12 @@ extern "C" {
 	  for (k = 0; k < J; k++) {
 	    tmp_JJ[k * J + k] += omegaOcc[k]; 
 	  } // k
-          F77_NAME(dpotrf)(lower, &J, tmp_JJ, &J, &info); 
+          F77_NAME(dpotrf)(lower, &J, tmp_JJ, &J, &info FCONE); 
           if(info != 0){error("c++ error: dpotrf on A.w failed\n");}
-          F77_NAME(dpotri)(lower, &J, tmp_JJ, &J, &info); 
+          F77_NAME(dpotri)(lower, &J, tmp_JJ, &J, &info FCONE); 
           if(info != 0){error("c++ error: dpotri on A.w failed\n");}
-          F77_NAME(dsymv)(lower, &J, &one, tmp_JJ, &J, tmp_JD, &inc, &zero, tmp_JD2, &inc);
-          F77_NAME(dpotrf)(lower, &J, tmp_JJ, &J, &info); 
+          F77_NAME(dsymv)(lower, &J, &one, tmp_JJ, &J, tmp_JD, &inc, &zero, tmp_JD2, &inc FCONE);
+          F77_NAME(dpotrf)(lower, &J, tmp_JJ, &J, &info FCONE); 
 	  if(info != 0){error("c++ error: dpotrf on A.w failed\n");}
           // Args: destination, mu, cholesky of the covariance matrix, dimension
           mvrnorm(tmp_J1, tmp_JD2, tmp_JJ, J);
